tpDcc-libs-options
============================================================

Customizable and easy to use data library.

.. image:: https://img.shields.io/badge/Python-2.7-yellow?logo=python
    :target: https://www.python.com/

.. image:: https://img.shields.io/badge/Python-3.7-yellow?logo=python
    :target: https://www.python.com/

.. image:: https://img.shields.io/badge/Maya-2018-green?logo=autodesk
    :target: https://www.autodesk.com/

.. image:: https://img.shields.io/badge/Maya-2019-green?logo=autodesk
    :target: https://www.autodesk.com/

.. image:: https://img.shields.io/badge/Maya-2020-green?logo=autodesk
    :target: https://www.autodesk.com/

.. image:: https://travis-ci.com/tpDcc/tpDcc-libs-options.svg?branch=master&kill_cache=1
    :target: https://travis-ci.com/tpDcc/tpDcc-libs-options

.. image:: https://coveralls.io/repos/github/tpDcc/tpDcc-libs-options/badge.svg?branch=master&kill_cache=1
    :target: https://coveralls.io/github/tpDcc/tpDcc-libs-options?branch=master

.. image:: https://img.shields.io/badge/docs-sphinx-orange
    :target: https://tpDcc.github.io/tpDcc-libs-options

.. image:: https://img.shields.io/github/license/tpDcc/tpDcc-libs-options
    :target: https://github.com/tpDcc/tpDcc-libs-options/blob/master/LICENSE

.. image:: https://img.shields.io/pypi/v/tpDcc-libs-options?branch=master&kill_cache=1
    :target: https://pypi.org/project/tpDcc-libs-options

.. image:: https://img.shields.io/badge/code_style-pep8-blue
    :target: https://www.python.org/dev/peps/pep-0008/